(*
 Sungsoon Jang, The LET Project, KAIST

 Copyright(c) 2001 Research On Program Analysis System
 National Creative Research Initiative Center
 Korea Advanced Institute of Science & Technology
 http://ropas.kaist.ac.kr

 All rights reserved. This file is distributed under the terms of
 an Open Source License.
*)

open Format
open List
open Unix
(************************************************)
(*                                              *)
(*  Analysis Part: Grouping Similar Files       *)
(*                                              *)
(************************************************)

fun is_group a [] lt = true
  | is_group a (h::l) lt =
        (exists (fn (b,i,_) => (a = b && h = i) || ( a = i && h = b )) lt)
            && is_group a l lt
fun select a [] = ([],[])
  | select a (h::l) =
      if exists (fn x => x = a) h then (filter (fn x => x <> a) h, l)
      else let val (sh,sl) = select a l in (sh,h::sl) end
fun analysis [] lt = []
  | analysis ((a,b,_)::l) lt =
    let
      val ll = analysis l lt
      val (ga,la) = select a ll
      val (gb,lb) = select b la
      val is_group_b_ga = is_group b ga lt
      val is_group_a_gb = is_group a gb lt
    in
      if exists (fn x => x = b) ga then ll
      else ([a,b] @ ga @ gb)::lb
    end

fun grouping (n,l) is =
  let
    val compare_number = length l
    val average = if compare_number = 0 then 0.0
		else (fold_right (fn (_,_,n) m => (n:real) + m) l 0.0:real)
           / (float_of_int compare_number)
    val ll = filter (fn (_,_,n) => n >= is) l
    val result = analysis ll ll
  in
    printf "\nTotal %d files are compared\n" n;
    printf "Average is %f\n" average;
    if result = [] then print_string "No clones are detected\n"
    else List.iter (fn l => print_string "("; List.iter (printf "%s ") l;
              print_string ")\n\n") result
  end

(**************** get file_names ********************)
val back_flag = ref false
val pre_char = ref '\000'
fun get_char() = if !back_flag then (back_flag:=false; !pre_char)
                 else input_char Pervasives.stdin
fun get_back c = (back_flag:=true;pre_char:=c)

fun remove_blank() =
  let
    val c = get_char()
  in
    if List.exists (fn x => x=c) [' ','\012','\009','\010','\013'] 
        then remove_blank() else get_back c
  end
    
fun get_token() =
  let
    val c = get_char()
  in
    if List.exists (fn x => x=c) [' ','\012','\009','\010','\013']
        then ""
        else String.make 1 c ^ get_token()
  end

fun read_token() = (remove_blank();get_token())

fun get_files () = read_token()::get_files() handle End_of_file => []
// get filenames from stdin

fun get_files_from_dir dir =
// get filenames from the directory
  let
    val d = Sys.opendir dir
    fun f () =
      let
        val s = if String.get dir 0 = '.' then
                    Sys.readdir d
                else if String.get dir (String.length dir - 1) = '/' then
                    dir^Sys.readdir d
                else dir^"/"^Sys.readdir d
      in
        if (stat s).st_kind = S_REG then
            s::f ()
        else
            f ()
       end handle End_of_file => []
   in
     f()
   end

(*************************************************)
(*												 *)
(*			Argument Process and Main			 *)
(*												 *)
(*************************************************)

type language = NML | C | JAVA | SCHEME
val inter_similarity = ref 0.0
val is_flag = ref false		// inter similarity and flag

val directory = ref ""
val d_flag = ref false		// directory name and flag

val lang = ref NML			// language specification. Default is nML

val optionlist =
  [("-is",Arg.Float(fn r => inter_similarity:=r;is_flag:=true),
  	"     <num> is inter similarity, which must be a real number between [0,1]"),
   ("-d", Arg.String(fn s => directory:=s;d_flag:=true),
   	"      checks clones among files in the <directory>"),
   ("-nml",Arg.Unit(fn () => lang:=NML),
   				"    detects clones among nML programs."),
   ("-c",  Arg.Unit(fn () => lang:=C),
   				"      detects clones among C programs"),
   ("-java",Arg.Unit(fn () => lang:=JAVA),
   				"   detects clones among JAVA programs"),
   ("-scheme",Arg.Unit(fn () => lang:=SCHEME),
   				" detects clones among SCHEME programs"),
   ("-help",Arg.Unit(fn()=>()),
   				"   display this list of options")]

(******** For printing the clonecheck result ***************)
fun pp (n,l) =
  let
    val compare_number = length l
    val average = if compare_number = 0 then 0.0
		else (fold_right (fn (_,_,n) m => (n:real) + m) l 0.0:real)
           / (float_of_int compare_number)
  in
    printf "\nTotal %d files are compared\n" n;
    printf "Average is %f\n" average;
    List.iter (fn (a,b,n) => printf "%s %s %f\n" a b n) l
  end
(**************************************************)

fun main() = 
	if not !is_flag then
		print_string "The -is flag should be specified\n"
	else if !inter_similarity < 0.0 orelse !inter_similarity > 1.0 then
		print_string "The inter similarity must be between 0 and 1\n"
    else let
		val l = if !d_flag then get_files_from_dir !directory else get_files()
	in
		// iter (fn s => print_string s;print_char '\n') l
		grouping
		(case !lang of
		  NML    => Lang_nML.compares (Lang_nML.abstract (Lang_nML.parsel l))
		| C      => Compare.compares (Lang_C.abstract (Lang_C.parsel l))
		| JAVA   => Compare.compares (Lang_JAVA.abstract (Lang_JAVA.parsel l))
		| SCHEME => Compare.compares (Lang_SCHEME.abstract (Lang_SCHEME.parsel l))
		) !inter_similarity
	end handle 
		Unix_error(_,_,s) => printf "%s doesn't exist or invalid directory\n" s

val others = fn _ => ()
    
val usage = "Usage: clck -is <num> [-nml | -c | -java | -scheme] [-d <directory>]\nOptions are:"
val _ = (Arg.parse optionlist others usage; main())

