(*
 Sunae Seo, The LET Project, KAIST

 Copyright(c) 2001 Research On Program Analysis System
 National Creative Research Initiative Center
 Korea Advanced Institute of Science & Technology
 http://ropas.kaist.ac.kr

 All rights reserved. This file is distributed under the terms of
 an Open Source License.
*)

(* Abstract syntax tree definition of java parser *)

structure Ast_gen =
struct

type lrbrack = LRBrack

// 19.5) Names 
type name = SName of string | LName of name * string

// 19.4) Types, Values and Variables
// primitive types
type ptype 
  = Byte | Short | Int | Long | Char
  | Float | Double
  |  Boolean

// reference types
type rtype 
  = ClassInterfTy of name            // class or interface type
  | ArrayTy1 of ptype * lrbrack list // array type with primitive type
  | ArrayTy2 of name * lrbrack list  // array type with user-defined name type 

type ttype = PrimTy of ptype | RefTy of rtype

// 19.7) Modifier 
type modifier 
  = Public | Protected | Private 
  | Static
  | Abstract | Final | Native | Synchronized | Transient 
  | Volatile
  | Strictfp

// 19.12) Expressions
type fieldname 
  = Name of name                    // name 
  | PrimName of primary * name      // primary.SName
  | SuperName of name               // super.SName
  | NameSuperName of name * name    // name.super.SName

and array_acc 
  = SArrayAcc of name * expr    // name[expr]
  | CArrayAcc of primary * expr // primary[expr] 
     // here, primary doesn't include ArrayCreatExpr(..)

and primary 
  = PExpr of expr   // (expression)
  | PThis           // "this" expr
  | PInt of int 
  | PLInt of string 
  | PFloat of string
  | PBool of bool
  | PChar of char
  | PString of string
  | PNull     // literal     
  | PClassInstanceCreat of 
        primary option * ttype * expr list * (class_body_dec list) option
     // primary.class type name (arg list) {class body}
  | PFieldAcc of fieldname
  | PMethodInv of fieldname * expr list  
             // method_name (arg list)
  | PArrayAcc of array_acc
  | PPClass of ptype   // primitive_type.class
  | PVClass    // void.class
  | PAClass of rtype   // array_type.class
  | PNClass of name  // name.class
  | PNThis of name  // name.this
  | PArrayCreat1 of ttype * expr_brack list * lrbrack list    
           // type [expr][expr]...[expr][][]...[]
  | PArrayCreat2 of ttype * lrbrack list * array_init
           // type []...[] = array_initializer

and unary_op 
  =  UPlus | UMinus
  | UPostIncr | UPostDecr
  | UPreIncr | UPreDecr
  | UCompare | UNot
  | UCast1 of ptype * lrbrack list 
  | UCast2 of expr
  | UCast3 of name * lrbrack list 

and binary_op 
  =  BOr  | BXOr | BAnd
  | BEqEq | BNotEq
  | BLt   | BGt  | BLtEq | BGtEq
  | BLShift | BRShift | BURShift
  | BPlus | BMinus | BMult | BDiv | BMod

and cond_expr 
  =  PrimaryExpr of primary
  | NameExpr of name 
  | UnaryExpr of unary_op * cond_expr
  | AndAndExpr of cond_expr * cond_expr 
  | OrOrExpr of cond_expr * cond_expr
     // not included in Binary because of short circuit
  | ConditionalExpr of cond_expr * expr * cond_expr 
  | InstanceOfExpr of cond_expr * rtype
  | BinExpr of binary_op * cond_expr * cond_expr

and assign_op 
  =  AEq | AMultEq | ADivEq | AModEq | APlusEq | AMinusEq 
  | ALShiftEq | ARShiftEq | AURShiftEq
  | AAndEq | AXOrEq | AOrEq

and left_hand_side 
  = LHSName of name 
  | LHSFieldAcc of fieldname 
  | LHSArrayAcc of array_acc

and assign =  left_hand_side * assign_op * expr  

and expr = Expression of cond_expr 
  | Assignment of assign

and expr_brack = expr   

// 19.12) Statements

and block_stmt = BSVarDecl of final_option * ttype * var_dec list //SName 
               | BSStmt of stmt
               | BSClassDec of class_dec
               | BSInterfDec of interf_dec

and stmt = BlockStmt of block_stmt list
         |   EmptyStmt
         |   ExprStmt of expr
      (* here, expr is stmt_expr, which cantains only 
        Assignment(..),
        Expression(UnaryExpr (UPreIncr, cond_expr)),
        Expression(UnaryExpr (UPreDecr, cond_expr)),
        Expression(UnaryExpr (UPostIncr, cond_expr)),
        Expression(UnaryExpr (UPostDecr, cond_expr)),
        Expression(PrimaryExpr (MethodInvExpr (..)),
        Expression(Primary (ClassInstanceCreate(..)))
      *)

        |   SwitchStmt of expr * (switch_label list * block_stmt list ) list 
        |   DoStmt  of stmt * expr
        |   BreakStmt of name option  // only SName is possible
        |   ContinueStmt of name option // only SName is possible
        |   ReturnStmt of expr option
        |   SynchStmt of expr * block_stmt list
        |   ThrowStmt of expr
        |   TryStmt of block_stmt list * catch_clause list * block_stmt list
          // try{..} catch .. catch(){} finally {}
        |   LabeledStmt of name * stmt   //only SName is possible
        |   IfThenStmt of expr * stmt 
        |   IfThenElseStmt of expr * stmt * stmt 
        |   WhileStmt of expr * stmt 
        |   ForStmt of for_init option * expr option * expr list * stmt 
    // for (for_init option; expr option; expr list) {stmt} 
    // here, expr of 'expr list' is stmt_expr 

    // Note that `then' part of if-then-else stmt cannot
    // contain if-then stmt directly
    // because of ambiguity

and switch_label = Default
                 | Case of expr

and catch_clause = Catch of formal_para * block_stmt list

and for_init = ForInit1 of expr list // here, expr is stmt_expr 
             | ForInit2 of final_option * ttype * var_dec list //SName

// 19.8) Classes

// 19.8.1) Class Decaration
and class_dec = 
 modifier list * name * ttype option * ttype list * class_body_dec list 
   // modifiers + class name(SName) + super class names + interface names + class body 
and class_body_dec = 
      FieldDec of modifier list * ttype * var_dec list 
    | MethodDec of method_head * block_stmt list  // method_head + body
    | ClassDec of class_dec
    | InterfDec of interf_dec
    | StaticInit of block_stmt list
    | ConstrDec of 
       modifier list * name * formal_para list * ttype list * constr_body
   //modifer + constructor_name + para list(SName) + throw option + body
    | BlockDec of block_stmt list 
    | AbsMethodDec of method_head  

    (* class_body_dec for class_dec is 
       FieldDec, MethodDec, ClassDec, 
       InterfDec, StaticInit, ConstrDec and BlockDec.

       class_body_dec for interf_dec is
       AbsMeThodDec, ClassDec, InterfDec and FieldDec.

       but in interf_dec case, it is need to semantically check 
       that modifiers of field declaration include 
       only PUBIC, STATIC, or FINAL.  
       Other modifiers are disallowed  *)

// 19.8.2) Field Declarations
and var_init = VarInitExpr of expr
              | VarInitArray of array_init
and array_init = ArrInitC of var_init list
                | ArrInitNC of var_init list

and var_dec = VarId of name * lrbrack list  // only SName is possible
    | VarInitId of name * lrbrack list * var_init 
       // only SName is possible


// 19.8.3) Method Declarations
and final_option = FinalNo | FinalYes 

and formal_para = FormalPara of final_option * ttype * name * lrbrack list 
       // only SName is possible

and method_head = 
  modifier list * ttype option 
  * name * formal_para list * lrbrack list * ttype list 
 // modifer + return type(None for VOID, Some for other types) 
 //  + constructor_name(SName) + para list(SName) + lrbrack + throw option

// 19.8.5) Constructor Declarations
and constr_body =  constr_invok option * block_stmt list 
   // explicit constructor invokation + real body
and constr_invok = ThisCall of expr list // argument list 
                 | SuperCall of expr list
                 | PrimThisCall of primary * expr list
                 | PrimSuperCall of primary * expr list
 
// 19.9.1) Interface Declaration
and interf_dec =  
 modifier list * name * ttype list * class_body_dec list 
 // modifiers + interface name + extends interface name + interface body

// 19.6) Packages 
type pkg_dec = name 
type imp_dec = SImp of name | MImp of name 
type typ_dec = TNothing 
    | TClassDec of class_dec 
    | TInterfDec of interf_dec  

type top_dec = CompileUnit of pkg_dec option * imp_dec list * typ_dec list 
     // package decl + import decl + type decl

end
