(*
 Sunae Seo, The LET Project, KAIST

 Copyright(c) 2001 Research On Program Analysis System
 National Creative Research Initiative Center
 Korea Advanced Institute of Science & Technology
 http://ropas.kaist.ac.kr

 All rights reserved. This file is distributed under the terms of
 an Open Source License.
*)

(* Lex file for java parser(JDK 1.2) *)
(* Last modification date : 2001/7/23 *)
(* First version is initialized in 2001/5/22, by saseo *)

{
open Java_parser

(* verbose is used for printing tokens when debuggint *)
fun verbose s = (* print_string s; print_newline () *) ()
fun fatal_error msg = raise (Print_err.Lex_err (msg, Print_err.get_ln ()))

(* The table of keywords *)

(***************** saseo -- from ~/n/utils/misc.ml **************)

fun create_hashtable size init =
  let val tbl = Hashtbl.create size 
  in
     List.iter (fn (key, data) => Hashtbl.add tbl key data) init;
     tbl
  end

(****************************************************************)

val keyword_table = 
  create_hashtable 149 [
    ("null", NULL_LITERAL),
    ("true", BOOLEAN_LITERAL(True)),
    ("false", BOOLEAN_LITERAL(False)),
    ("abstract", ABSTRACT),
    ("boolean", BOOLEAN),
    ("break", BREAK),
    ("byte", BYTE),
    ("case", CASE),
    ("catch", CATCH),
    ("char", CHAR),
    ("class", CLASS),
    ("const", CONST),
    ("continue", CONTINUE),
    ("default", DEFAULT),
    ("do", DO),
    ("double", DOUBLE),
    ("else", ELSE),
    ("extends", EXTENDS),
    ("final", FINAL),
    ("finally", FINALLY),
    ("float", FLOAT),
    ("for", FOR),
    ("goto", GOTO),
    ("if", IF),
    ("implements", IMPLEMENTS),
    ("import", IMPORT),
    ("instanceof", INSTANCEOF),
    ("int", INT),
    ("interface", INTERFACE),
    ("long", LONG),
    ("native", NATIVE),
    ("new", NEW),
    ("package", PACKAGE),
    ("private", PRIVATE),
    ("protected", PROTECTED),
    ("public", PUBLIC),
    ("return", RETURN),
    ("short", SHORT),
    ("static", STATIC),
    ("strictfp", STRICTFP),
    ("super", SUPER),
    ("switch", SWITCH),
    ("synchronized", SYNCHRONIZED),
    ("this", THIS),
    ("throw", THROW),
    ("throws", THROWS),
    ("transient", TRANSIENT),
    ("try", TRY),
    ("void", VOID),
    ("volatile", VOLATILE),
    ("while", WHILE)
  ]

(* To buffer string literals *)

val initial_string_buffer = String.create 256
val string_buff = ref initial_string_buffer
val string_index = ref 0

fun reset_string_buffer () =
  (string_buff := initial_string_buffer;
   string_index := 0)

fun store_string_char c =
  (if !string_index >= String.length (!string_buff) then 
   (
    let val new_buff = String.create (String.length (!string_buff) * 2)
 in
      String.blit (!string_buff) 0 new_buff 0 (String.length (!string_buff));
      string_buff := new_buff
 end
   );
   String.unsafe_set (!string_buff) (!string_index) c;
   incr string_index)

fun get_stored_string () =
  let val s = String.sub (!string_buff) 0 (!string_index)
  in
    string_buff := initial_string_buffer; s
  end

(* To translate escape sequences *)

val char_for_backslash =
  case Sys.os_type of
    "Unix" | "Win32" =>
     (fn
        'n' => '\012' // LineTerminator
      | 'r' => '\015' // CR - carrage return
      | 'b' => '\010' // BS - back space
      | 't' => '\011' // HT - horizontal tab
      | 'f' => '\014' // FF - form feed
      | c   => c)
  | "MacOS" =>
     (fn
        'n' => '\013'
      | 'r' => '\010'
      | 'b' => '\010'
      | 't' => '\011'
      | 'f' => '\014' // I don't know MacOS formfeed character..just copy it 
      | c   => c)
  | x => fatal_error ("Lexer: unknown system type")

fun char_for_octal_code lexbuf i maxsize =
  let val c = ref 0
  in
   (for j=0; j<maxsize; j+1 
     do  
     c := (!c)*8 + (Char.code(Lexing.lexeme_char lexbuf (i+j))-48)
    end);
   if (!c) > 0xFF  then fatal_error ("Illegal escape character"); 
   Char.chr(land !c 0xFF )
  end

(* To store the position of the beginning of a string and comment *)
val string_start_pos = ref 0
and comment_start_pos = ref 0

}

val blank = [' ' '\008' '\009' '\011' '\013']
val newline = '\010'
val alphabet = ['A'-'Z' 'a'-'z']
val firstchar = ['A'-'Z' 'a'-'z' '$' '_']
val followchar = 
  ['A'-'Z' 'a'-'z' '_' '$' '0'-'9'] 
val id = firstchar followchar*
(* saseo -- identifier  ǰ ϴ *)

val decimal_literal = ['0'-'9']+
val hex_literal = '0' ['x' 'X'] ['0'-'9' 'A'-'F' 'a'-'f']+
val oct_literal = '0' ['o' 'O'] ['0'-'7']+
val bin_literal = '0' ['b' 'B'] ['0'-'1']+
val long_literal = 
 (decimal_literal | hex_literal | oct_literal | bin_literal) ['l' 'L']

val float_literal =
  ['0'-'9']+ ('.' ['0'-'9']+)? (['e' 'E'] ['+' '-']? ['0'-'9']+)?
val symbolchar =
  ['\\' '!' '$' '%' '&' '*' '+' '-' '.' '/' ':' '<' '=' '>' '?' '@' '^' '|' '~' '#']


rule token = parse
    blank +    { token lexbuf }
  | newline    { Print_err.incr_ln (); token lexbuf }

 (* Separators *)
  | "("   { verbose "("; LPAREN }
  | ")"   { verbose ")"; RPAREN }
  | "{"   { verbose "{"; LBRACE }
  | "}"   { verbose "}"; RBRACE }
  | "["   { verbose "["; LBRACK }
  | "]"   { verbose "]"; RBRACK }
  | ";"   { verbose ";"; SEMICOLON }
  | ","   { verbose ","; COMMA }

    (* Operators *)
  | "="  { verbose "="; EQ }
  | ">"  { verbose ">"; GT }
  | "<"  { verbose "<"; LT }
  | "!"  { verbose "!"; NOT }
  | "~"  { verbose "~"; COMP }
  | "?"  { verbose "?"; QUESTION }
  | ":"  { verbose ":"; COLON }
  | "&"  { verbose "&"; AND }
  | "|"  { verbose "|"; OR }
  | "+"  { verbose "+"; PLUS }
  | "-"  { verbose "-"; MINUS }
  | "*"  { verbose "*"; MULT }
  | "/"  { verbose "/"; DIV }
  | "^"  { verbose "^"; XOR }
  | "%"  { verbose "%"; MOD }
  | "==" { verbose "=="; EQEQ }
  | "<=" { verbose "<="; LTEQ }
  | ">=" { verbose ">="; GTEQ }
  | "!=" { verbose "!="; NOTEQ }
  | "&&" { verbose "&&"; ANDAND }
  | "||" { verbose "||"; OROR }
  | "++" { verbose "++"; PLUSPLUS }
  | "--" { verbose "--"; MINUSMINUS }
  | "<<" { verbose "<<"; LSHIFT }
  | ">>" { verbose ">>"; RSHIFT }
  | ">>>"{ verbose ">>>"; URSHIFT }
  | "+=" { verbose "+="; PLUSEQ }
  | "-=" { verbose "-="; MINUSEQ }
  | "*=" { verbose "*="; MULTEQ }
  | "/=" { verbose "/="; DIVEQ }
  | "&=" { verbose "&="; ANDEQ }
  | "|=" { verbose "|="; OREQ }
  | "^=" { verbose "^="; XOREQ }
  | "%=" { verbose "%="; MODEQ }
  | "<<=" { verbose "<<="; LSHIFTEQ }
  | ">>=" { verbose ">>="; RSHIFTEQ }
  | ">>>=" { verbose ">>>="; URSHIFTEQ }
  | "."  { verbose "."; DOT }

    (* characters  *)
  | "'" [^ '\\' '\''] "'"
      { verbose "Char_literal"; 
   CHARACTER_LITERAL (Lexing.lexeme_char lexbuf 1) }
  | "'" '\\' ['\\' '\'' '"' 'n' 't' 'b' 'r' 'f'] "'"
      { verbose "Char_literal"; 
   CHARACTER_LITERAL (char_for_backslash (Lexing.lexeme_char lexbuf 2)) }
  | "'" '\\' ['0'-'3'] ['0'-'7'] ['0'-'7'] "'"
      { verbose "Char_literal"; 
   CHARACTER_LITERAL (char_for_octal_code lexbuf 2 3) }
  | "'" '\\' ['0'-'7'] ['0'-'7'] "'"
      { verbose "Char_literal"; 
   CHARACTER_LITERAL (char_for_octal_code lexbuf 2 2) }
  | "'" '\\' ['0'-'7'] "'"
      { verbose "Char_literal"; 
   CHARACTER_LITERAL (char_for_octal_code lexbuf 2 1) }

 (* strings *)
  | "\""
      { reset_string_buffer();
        let val string_start = Lexing.lexeme_start lexbuf
   in verbose "String_literal";
    string_start_pos := string_start;
            string lexbuf;
      Interop.lexing_field_update_lex_start_pos
       (lexbuf, string_start - (Interop.lexing_field_lex_abs_pos lexbuf));
            STRING_LITERAL (get_stored_string())
  end }

 (* NumericLiterals *)
  | decimal_literal | hex_literal | oct_literal | bin_literal
      { verbose "Int_literal"; INTEGER_LITERAL (int_of_string(Lexing.lexeme lexbuf)) }
  | long_literal 
     { let val s = Lexing.lexeme lexbuf 
        in
    verbose "LongInt_literal";
    LONG_INTEGER_LITERAL s
//      (int_of_string( String.sub s 0 ((String.length s) - 1) ))
        end
   }
  | float_literal
      { verbose "Float_literal"; FLOATING_POINT_LITERAL (Lexing.lexeme lexbuf) }

 (* Keywords and Identifiers *)
  | id
      { let val s = Lexing.lexeme lexbuf
     in
    verbose s;
          (Hashtbl.find keyword_table s) handle Not_found => IDENTIFIER s 
  end }

    (* Comments *)
  | "//"[^'\n']* '\n' { Print_err.incr_ln (); token lexbuf } (* line comment *)
  | "/*"              (* multi-line comment *)
      { comment_start_pos := Lexing.lexeme_start lexbuf;
        comment lexbuf;
        token lexbuf }
  | eof { EOF }
  | _ 
    {fatal_error ("Illegal charater")}


and string = parse
    '"'
      { () }
  | '\\' ['\\' '\'' '"' 'f' 'n' 't' 'b' 'r']
      { store_string_char(char_for_backslash(Lexing.lexeme_char lexbuf 1));
        string lexbuf }
  | '\\' ['0'-'3'] ['0'-'7'] ['0'-'7']
      { store_string_char (char_for_octal_code lexbuf 2 3);
        string lexbuf }
  | '\\' ['0'-'7'] ['0'-'7']
      { store_string_char (char_for_octal_code lexbuf 2 2);
        string lexbuf }
  | '\\' ['0'-'7']
      { store_string_char (char_for_octal_code lexbuf 2 1);
        string lexbuf }
  | '\n' 
      { fatal_error ("'\\n' is Invalid Character in string literal")}
  | eof
      { fatal_error ("Unterminated_string") }
  | _
      { store_string_char(Lexing.lexeme_char lexbuf 0);
        string lexbuf }

and comment = parse
    "*/" {()}
  | "\n" {Print_err.incr_ln (); comment lexbuf } 
  | eof
      { fatal_error ("Unterminated_comment") }
  | _
      { comment lexbuf }

